package example.hello;

import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;

/**
 * Adapted from the "Hello World" example from Sun at 
 * http://java.sun.com/javase/6/docs/technotes/guides/rmi/hello/hello-world.html
 *
 * This is the client program that access the remote Hello object being presented via RMI
 */
public class Client {

	public Client() {}
	
	/**
	 * Run the client
	 * @param host The URL of the RMI server. null mean use localhost
	 */
	public void run(String host){

		try {
			Registry registry = LocateRegistry.getRegistry(host); // if host==null, then look in localhost
			Hello stub = (Hello) registry.lookup("Hello");   // get the stub for the Hello object
			String response = stub.sayHello(); // Run a method on the Hello object
			System.out.println("response: " + response);  
		} catch (Exception e) {
			System.err.println("Client exception: " + e.toString());
			e.printStackTrace();
		}		
	}

	public static void main(String[] args) {
		String host = (args.length < 1) ? null : args[0];
		(new Client()).run(host);
	}
}
